PipFlutterPlayerControlsState<T extends StatefulWidget> class abstract

Base class for both material and cupertino controls

Inheritance

Properties

context → BuildContext
The location in the tree where this widget builds.
no setterinherited
controlsNotVisible ↔ bool
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
latestValue → VideoPlayerValue?
no setter
mounted → bool
Whether this State object is currently in a tree.
no setterinherited
pipFlutterPlayerController → PipFlutterPlayerController?
no setter
pipFlutterPlayerControlsConfiguration → PipFlutterPlayerControlsConfiguration
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
widget → T
The current configuration.
no setterinherited

Methods

activate() → void
Called when this object is reinserted into the tree after having been removed via deactivate.
inherited
build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
inherited
buildLTRDirectionality(Widget child) → Widget
Builds directionality widget which wraps child widget and forces left to right directionality.
cancelAndRestartTimer() → void
changePlayerControlsNotVisible(bool notVisible) → void
Called when player controls visibility should be changed.
deactivate() → void
Called when this object is removed from the tree.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
didChangeDependencies() → void
Called when a dependency of this State object changes.
inherited
didUpdateWidget(covariant T oldWidget) → void
Called whenever the widget configuration changes.
inherited
dispose() → void
Called when this object is removed from the tree permanently.
inherited
initState() → void
Called when this object is inserted into the tree.
inherited
isLoading(VideoPlayerValue? latestValue) → bool
Latest value can be null
isVideoFinished(VideoPlayerValue? videoPlayerValue) → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onShowMoreClicked() → void
reassemble() → void
Called whenever the application is reassembled during debugging, for example during hot reload.
inherited
setState(VoidCallback fn) → void
Notify the framework that the internal state of this object has changed.
inherited
skipBack() → void
skipForward() → void
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited