HlsPlaylist class abstract

Implementers

Constructors

HlsPlaylist({required String? baseUri, required List<String> tags, required bool hasIndependentSegments})

Properties

baseUri → String?
The base uri. Used to resolve relative paths.
final
hashCode → int
The hash code for this object.
no setterinherited
hasIndependentSegments → bool
Whether the media is formed of independent segments, as defined by the #EXT-X-INDEPENDENT-SEGMENTS tag.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tags → List<String>
The list of tags in the playlist.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited